==> eiffelstudio-16.05.tar: F_code/C14/et660.c <==
/*
 * Code for class ET_FORMAL_ARGUMENT_LIST
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "et660.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {ET_FORMAL_ARGUMENT_LIST}.make */
void F1529_15828 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tr1 = RTOSCF(5912,F599_5912,(RTCV(RTOSCF(7402,F893_7402,(Current)))));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	tr1 = RTOSCF(5917,F599_5917,(RTCV(RTOSCF(7402,F893_7402,(Current)))));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
	F887_7333(Current);
	RTLE;
}

/* {ET_FORMAL_ARGUMENT_LIST}.make_with_capacity */
void F1529_15829 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tr1 = RTOSCF(5912,F599_5912,(RTCV(RTOSCF(7402,F893_7402,(Current)))));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	tr1 = RTOSCF(5917,F599_5917,(RTCV(RTOSCF(7402,F893_7402,(Current)))));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
	F887_7334(Current, arg1);
	RTLE;
}

/* {ET_FORMAL_ARGUMENT_LIST}.reset */
void F1529_15830 (EIF_REFERENCE Current)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLR(3,tr3);
	RTLIU(4);
	
	RTGC;
	loc2 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_0_0_0_);
	loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc2 - ((EIF_INTEGER_32) 1L));
	loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
	for (;;) {
		if ((EIF_BOOLEAN) (loc1 > loc2)) break;
		tr1 = *(EIF_REFERENCE *)(Current);
		/* INLINED CODE (SPECIAL.item) */
		tr3 = *((EIF_REFERENCE *)tr1 + (loc1));
		/* END INLINED CODE */
		tr1 = tr3;
		tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R12948[Dtype(tr1)-1680])(RTCW(tr1));
		F1682_16629(RTCW(tr1));
		loc1++;
	}
	RTLE;
}

/* {ET_FORMAL_ARGUMENT_LIST}.reset_qualified_anchored_types */
void F1529_15831 (EIF_REFERENCE Current)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	RTLD;
	
	RTLI(6);
	RTLR(0,Current);
	RTLR(1,loc3);
	RTLR(2,tr1);
	RTLR(3,tr2);
	RTLR(4,tr3);
	RTLR(5,loc4);
	RTLIU(6);
	
	RTGC;
	loc2 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_0_0_0_);
	loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc2 - ((EIF_INTEGER_32) 1L));
	loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
	for (;;) {
		if ((EIF_BOOLEAN) (loc1 > loc2)) break;
		loc3 = *(EIF_REFERENCE *)(Current);
		/* INLINED CODE (SPECIAL.item) */
		tr2 = *((EIF_REFERENCE *)loc3 + (loc1));
		/* END INLINED CODE */
		loc3 = tr2;
		loc3 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R12948[Dtype(loc3)-1680])(RTCW(loc3));
		loc3 = F1682_16631(RTCW(loc3));
		if ((EIF_BOOLEAN)(loc3 != loc4)) {
			(FUNCTION_CAST(void, (EIF_REFERENCE)) R13122[Dtype(loc3)-1734])(RTCW(loc3));
			loc4 = (EIF_REFERENCE) loc3;
		}
		loc1++;
	}
	RTLE;
}

/* {ET_FORMAL_ARGUMENT_LIST}.formal_argument */
EIF_REFERENCE F1529_15833 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,Result);
	RTLIU(3);
	
	RTGC;
	tr1 = F887_7335(Current, arg1);
	Result = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R12948[Dtype(tr1)-1680])(RTCW(tr1));
	RTLE;
	return Result;
}

/* {ET_FORMAL_ARGUMENT_LIST}.left_parenthesis */
EIF_REFERENCE F1529_15834 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


/* {ET_FORMAL_ARGUMENT_LIST}.right_parenthesis */
EIF_REFERENCE F1529_15835 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_2_);
}


/* {ET_FORMAL_ARGUMENT_LIST}.index_of */
EIF_INTEGER_32 F1529_15836 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_BOOLEAN tb1;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(5);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLR(3,tr3);
	RTLR(4,arg1);
	RTLIU(5);
	
	RTGC;
	loc2 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_0_0_0_);
	loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc2 - ((EIF_INTEGER_32) 1L));
	loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
	for (;;) {
		if ((EIF_BOOLEAN) (loc1 > loc2)) break;
		tr1 = *(EIF_REFERENCE *)(Current);
		/* INLINED CODE (SPECIAL.item) */
		tr3 = *((EIF_REFERENCE *)tr1 + (loc1));
		/* END INLINED CODE */
		tr1 = tr3;
		tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R12948[Dtype(tr1)-1680])(RTCW(tr1));
		tr1 = F1682_16630(RTCW(tr1));
		tb1 = F1843_18465(RTCW(tr1), arg1);
		if (tb1) {
			Result = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_0_0_0_);
			Result = (EIF_INTEGER_32) (EIF_INTEGER_32) (Result - loc1);
			loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc2 + ((EIF_INTEGER_32) 1L));
		} else {
			loc1++;
		}
	}
	RTLE;
	return Result;
}

/* {ET_FORMAL_ARGUMENT_LIST}.position */
EIF_REFERENCE F1529_15837 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,Result);
	RTLIU(3);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	Result = F1781_17804(RTCW(tr1));
	tb1 = '\0';
	tb2 = F1175_12047(RTCW(Result));
	if (tb2) {
		tb1 = (EIF_BOOLEAN) !F887_7340(Current);
	}
	if (tb1) {
		tr1 = F887_7336(Current);
		Result = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R12455[Dtype(tr1)-1510])(RTCW(tr1));
	}
	RTLE;
	return Result;
}

/* {ET_FORMAL_ARGUMENT_LIST}.first_leaf */
EIF_REFERENCE F1529_15838 (EIF_REFERENCE Current)
{
	GTCX
	
	
	return (EIF_REFERENCE) *(EIF_REFERENCE *)(Current + _REFACS_1_);
}

/* {ET_FORMAL_ARGUMENT_LIST}.last_leaf */
EIF_REFERENCE F1529_15839 (EIF_REFERENCE Current)
{
	GTCX
	
	
	return (EIF_REFERENCE) *(EIF_REFERENCE *)(Current + _REFACS_2_);
}

/* {ET_FORMAL_ARGUMENT_LIST}.process */
void F1529_15842 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	
	
	F209_2222(RTCW(arg1), Current);
}

/* {ET_FORMAL_ARGUMENT_LIST}.fixed_array */
static EIF_REFERENCE F1529_15843_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEV;
	RTGC;
	RTOSP (15843);
#define Result RTOSR(15843)
	RTOC_NEW(Result);
	{
		static EIF_TYPE_INDEX typarr0[] = {41,1679,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 41, _OBJSIZ_0_0_0_0_0_0_0_0_);
	}
	Result = (EIF_REFERENCE) tr1;
	RTOSE (15843);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F1529_15843 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(15843,F1529_15843_body,(Current));
}

void EIF_Minit660 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.01.10.1424.tar: F_code/C14/et660.c <==
/*
 * Code for class ET_FORMAL_ARGUMENT_LIST
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "et660.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {ET_FORMAL_ARGUMENT_LIST}.make */
void F1500_15071 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tr1 = RTOSCF(6071,F582_6071,(RTCV(RTOSCF(7891,F938_7891,(Current)))));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	tr1 = RTOSCF(6076,F582_6076,(RTCV(RTOSCF(7891,F938_7891,(Current)))));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
	F932_7819(Current);
	RTLE;
}

/* {ET_FORMAL_ARGUMENT_LIST}.make_with_capacity */
void F1500_15072 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tr1 = RTOSCF(6071,F582_6071,(RTCV(RTOSCF(7891,F938_7891,(Current)))));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	tr1 = RTOSCF(6076,F582_6076,(RTCV(RTOSCF(7891,F938_7891,(Current)))));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
	F932_7820(Current, arg1);
	RTLE;
}

/* {ET_FORMAL_ARGUMENT_LIST}.reset */
void F1500_15073 (EIF_REFERENCE Current)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLR(3,tr3);
	RTLIU(4);
	
	RTGC;
	loc2 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_0_0_0_);
	loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc2 - ((EIF_INTEGER_32) 1L));
	loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
	for (;;) {
		if ((EIF_BOOLEAN) (loc1 > loc2)) break;
		tr1 = *(EIF_REFERENCE *)(Current);
		/* INLINED CODE (SPECIAL.item) */
		tr3 = *((EIF_REFERENCE *)RTCW(tr1) + (loc1));
		/* END INLINED CODE */
		tr1 = tr3;
		tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R12117[Dtype(tr1)-1626])(RTCW(tr1));
		F1628_15733(RTCW(tr1));
		loc1++;
	}
	RTLE;
}

/* {ET_FORMAL_ARGUMENT_LIST}.reset_qualified_anchored_types */
void F1500_15074 (EIF_REFERENCE Current)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	RTLD;
	
	RTLI(6);
	RTLR(0,Current);
	RTLR(1,loc3);
	RTLR(2,tr1);
	RTLR(3,tr2);
	RTLR(4,tr3);
	RTLR(5,loc4);
	RTLIU(6);
	
	RTGC;
	loc2 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_0_0_0_);
	loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc2 - ((EIF_INTEGER_32) 1L));
	loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
	for (;;) {
		if ((EIF_BOOLEAN) (loc1 > loc2)) break;
		loc3 = *(EIF_REFERENCE *)(Current);
		/* INLINED CODE (SPECIAL.item) */
		tr2 = *((EIF_REFERENCE *)RTCW(loc3) + (loc1));
		/* END INLINED CODE */
		loc3 = tr2;
		loc3 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R12117[Dtype(loc3)-1626])(RTCW(loc3));
		loc3 = F1628_15735(RTCW(loc3));
		if ((EIF_BOOLEAN)(loc3 != loc4)) {
			(FUNCTION_CAST(void, (EIF_REFERENCE)) R12353[Dtype(loc3)-1708])(RTCW(loc3));
			loc4 = (EIF_REFERENCE) loc3;
		}
		loc1++;
	}
	RTLE;
}

/* {ET_FORMAL_ARGUMENT_LIST}.formal_argument */
EIF_REFERENCE F1500_15076 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,Result);
	RTLIU(3);
	
	RTGC;
	tr1 = F932_7821(Current, arg1);
	Result = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R12117[Dtype(tr1)-1626])(RTCW(tr1));
	RTLE;
	return Result;
}

/* {ET_FORMAL_ARGUMENT_LIST}.left_parenthesis */
EIF_REFERENCE F1500_15077 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


/* {ET_FORMAL_ARGUMENT_LIST}.right_parenthesis */
EIF_REFERENCE F1500_15078 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_2_);
}


/* {ET_FORMAL_ARGUMENT_LIST}.index_of */
EIF_INTEGER_32 F1500_15079 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_BOOLEAN tb1;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(5);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLR(3,tr3);
	RTLR(4,arg1);
	RTLIU(5);
	
	RTGC;
	loc2 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_0_0_0_);
	loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc2 - ((EIF_INTEGER_32) 1L));
	loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
	for (;;) {
		if ((EIF_BOOLEAN) (loc1 > loc2)) break;
		tr1 = *(EIF_REFERENCE *)(Current);
		/* INLINED CODE (SPECIAL.item) */
		tr3 = *((EIF_REFERENCE *)RTCW(tr1) + (loc1));
		/* END INLINED CODE */
		tr1 = tr3;
		tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R12117[Dtype(tr1)-1626])(RTCW(tr1));
		tr1 = F1628_15734(RTCW(tr1));
		tb1 = F1818_17708(RTCW(tr1), arg1);
		if (tb1) {
			Result = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_0_0_0_);
			Result = (EIF_INTEGER_32) (EIF_INTEGER_32) (Result - loc1);
			loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc2 + ((EIF_INTEGER_32) 1L));
		} else {
			loc1++;
		}
	}
	RTLE;
	return Result;
}

/* {ET_FORMAL_ARGUMENT_LIST}.position */
EIF_REFERENCE F1500_15080 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,Result);
	RTLIU(3);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	Result = F1755_17047(RTCW(tr1));
	tb1 = '\0';
	tb2 = F1220_12595(RTCW(Result));
	if (tb2) {
		tb1 = (EIF_BOOLEAN) !F932_7826(Current);
	}
	if (tb1) {
		tr1 = F932_7822(Current);
		Result = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R11672[Dtype(tr1)-1478])(RTCW(tr1));
	}
	RTLE;
	return Result;
}

/* {ET_FORMAL_ARGUMENT_LIST}.first_leaf */
EIF_REFERENCE F1500_15081 (EIF_REFERENCE Current)
{
	GTCX
	
	
	return (EIF_REFERENCE) *(EIF_REFERENCE *)(Current + _REFACS_1_);
}

/* {ET_FORMAL_ARGUMENT_LIST}.last_leaf */
EIF_REFERENCE F1500_15082 (EIF_REFERENCE Current)
{
	GTCX
	
	
	return (EIF_REFERENCE) *(EIF_REFERENCE *)(Current + _REFACS_2_);
}

/* {ET_FORMAL_ARGUMENT_LIST}.process */
void F1500_15085 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	
	
	F212_2263(RTCW(arg1), Current);
}

/* {ET_FORMAL_ARGUMENT_LIST}.fixed_array */
static EIF_REFERENCE F1500_15086_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEV;
	RTGC;
	RTOSP (15086);
#define Result RTOSR(15086)
	RTOC_NEW(Result);
	{
		static EIF_TYPE_INDEX typarr0[] = {42,1625,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 42, _OBJSIZ_0_0_0_0_0_0_0_0_);
	}
	Result = (EIF_REFERENCE) tr1;
	RTOSE (15086);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F1500_15086 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(15086,F1500_15086_body,(Current));
}

void EIF_Minit660 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
